@@ -2,7 +2,7 @@ from setuptools import setup
 
 setup(
     name='lintest',
-    version='1.7.3',
+    version='1.7.0.6',
     author='Wang Lin',
     author_email='think_wl@163.com',
     packages=['lintest'],
@@ -14,6 +14,7 @@ setup(
         "setuptools",
         "urllib3",
         "PyMySQL",
+        "jsoncomparison",
         "chromedriver_autoinstaller"
     ]
 )
